@@ -2,6 +2,14 @@
 # -*- coding: utf-8 -*-
 import requests
 import re
+import sys
+PY2 = sys.version_info[0] == 2
+if PY2:
+    reload(sys)
+    sys.setdefaultencoding('utf-8')
+else:
+    pass
+
 
 
 class SpiderBase(object):
@@ -15,6 +23,7 @@ class HuangliSpider(SpiderBase):
 
     def get_current_calender(self):
         html = requests.get(self.api_url,headers=self.headers).text
+        html = str(html)
         re_pattern = "今日.*?年柱.*?<br />(.*?)</td>.*?月柱.*?<br />(.*?)</td>.*?日柱.*?<br />(.*?)</td>.*?时柱.*?<br />(.*?)</td>"
         r = re.search(re_pattern,html.encode("utf-8"))
         return r.group(1),r.group(2),r.group(3),r.group(4)
